==> koishi-decorators-v1.0.1.tar.bz2: koishi-decorators-v1.0.1/src/registry/registries/command-put.ts <==
import { Argv, Command, FieldCollector, Session, User } from 'koishi';
import {
  CommandOptionConfig,
  GenerateMappingStruct,
  KoishiCommandPutDef,
  MappingStruct,
} from '../../def';
import { MethodRegistry } from '../abstract-registry';

// eslint-disable-next-line @typescript-eslint/no-namespace
export namespace CommandPut {
  export interface ConfigMap {
    args: void;
    arg: number;
    argv: void;
    argvField: keyof Argv;
    option: CommandOptionConfig;
    user: FieldCollector<'user'>;
    channel: FieldCollector<'channel'>;
    username: boolean;
    sessionField: keyof Session;
  }

  export type Config<K extends keyof ConfigMap = keyof ConfigMap> =
    MappingStruct<ConfigMap, K>;

  export const preRegistry = new MethodRegistry<ConfigMap, void, [Command]>();

  preRegistry.extend('option', (data, cmd) =>
    cmd.option(data.name, data.desc, data.config),
  );

  preRegistry.extend('user', (data, cmd) => {
    if (data) {
      cmd.userFields(data);
    }
  });

  preRegistry.extend('channel', (data, cmd) => {
    if (data) {
      cmd.channelFields(data);
    }
  });

  preRegistry.extend('username', (data, cmd) => {
    if (data) {
      cmd.userFields(['name']);
    }
  });

  export const registry = new MethodRegistry<ConfigMap, any, [Argv, any[]]>();

  registry.extend('args', (data, argv, args) => args);
  registry.extend('arg', (data, argv, args) => args[data]);
  registry.extend('argv', (data, argv, args) => argv);
  registry.extend('argvField', (data, argv, args) => argv[data]);
  registry.extend('option', (data, argv, args) => argv.options[data.name]);
  registry.extend('user', (data, argv, args) => argv.session.user);
  registry.extend('channel', (data, argv, args) => argv.session.channel);
  registry.extend('username', (useDatabase, argv, args) => {
    if (useDatabase) {
      const user = argv.session.user as User.Observed<'name'>;
      if (user?.name) {
        return user?.name;
      }
    }
    return (
      argv.session.author?.nickname ||
      argv.session.author?.username ||
      argv.session.userId
    );
  });
  registry.extend('sessionField', (data, argv, args) => argv.session[data]);

  export function decorate<T extends keyof ConfigMap>(
    type: T,
    data?: ConfigMap[T],
  ): ParameterDecorator {
    return (obj, key: string, index) => {
      const objClass = obj.constructor;
      const list: Config<T>[] =
        Reflect.getMetadata(KoishiCommandPutDef, objClass, key) || [];
      list[index] = GenerateMappingStruct(type, data);
      Reflect.defineMetadata(KoishiCommandPutDef, list, objClass, key);
    };
  }
}

==> koishi-decorators-v1.2.2.tar.bz2: koishi-decorators-v1.2.2/src/registry/registries/command-put.ts <==
import { Argv, Command, Context, FieldCollector, Session, User } from 'koishi';
import {
  CommandOptionConfig,
  GenerateMappingStruct,
  KoishiCommandPutDef,
  MappingStruct,
  TemplateConfig,
} from '../../def';
import { MethodRegistry } from '../abstract-registry';
import { registerTemplate } from '../../utility';

// eslint-disable-next-line @typescript-eslint/no-namespace
export namespace CommandPut {
  export interface ConfigMap {
    args: void;
    arg: number;
    argv: void;
    argvField: keyof Argv;
    option: CommandOptionConfig;
    user: FieldCollector<'user'>;
    channel: FieldCollector<'channel'>;
    guild: FieldCollector<'channel'>;
    username: boolean;
    sessionField: keyof Session;
    renderer: string | undefined;
    template: TemplateConfig;
  }

  export type Config<K extends keyof ConfigMap = keyof ConfigMap> =
    MappingStruct<ConfigMap, K>;

  export const preRegistry = new MethodRegistry<
    ConfigMap,
    void,
    [Command, Context]
  >();

  preRegistry.extend('option', (data, cmd) =>
    cmd.option(data.name, data.desc, data.config),
  );

  preRegistry.extend('user', (data, cmd) => {
    if (data) {
      cmd.userFields(data);
    }
  });

  preRegistry.extend('channel', (data, cmd) => {
    if (data) {
      cmd.channelFields(data);
    }
  });

  preRegistry.extend('username', (data, cmd) => {
    if (data) {
      cmd.userFields(['name']);
    }
  });

  preRegistry.extend('template', (data, cmd, ctx) =>
    registerTemplate(data, ctx, cmd),
  );

  export const registry = new MethodRegistry<ConfigMap, any, [Argv, any[]]>();

  registry.extend('args', (data, argv, args) => args);
  registry.extend('arg', (data, argv, args) => args[data]);
  registry.extend('argv', (data, argv, args) => argv);
  registry.extend('argvField', (data, argv, args) => argv[data]);
  registry.extend('option', (data, argv, args) => argv.options[data.name]);
  registry.extend('user', (data, argv, args) => argv.session.user);
  registry.extend('channel', (data, argv, args) => argv.session.channel);
  registry.extend('guild', (data, argv, args) => argv.session.guild);
  registry.extend('username', (useDatabase, argv, args) => {
    if (useDatabase) {
      const user = argv.session.user as User.Observed<'name'>;
      if (user?.name) {
        return user?.name;
      }
    }
    return (
      argv.session.author?.nickname ||
      argv.session.author?.username ||
      argv.session.userId
    );
  });
  registry.extend('sessionField', (data, argv, args) => argv.session[data]);

  registry.extend('renderer', (data, argv, args) =>
    data
      ? // eslint-disable-next-line @typescript-eslint/ban-types
        (params: object) => argv.session.text(data, params)
      : // eslint-disable-next-line @typescript-eslint/ban-types
        (path: string, params: object) => argv.session.text(path, params),
  );
  registry.extend(
    'template',
    // eslint-disable-next-line @typescript-eslint/ban-types
    (data, argv, args) => (params: object) =>
      argv.session.text(`.${data.name}`, params),
  );

  export function decorate<T extends keyof ConfigMap>(
    type: T,
    data?: ConfigMap[T],
  ): ParameterDecorator {
    return (obj, key: string, index) => {
      const objClass = obj.constructor;
      const list: Config<T>[] =
        Reflect.getMetadata(KoishiCommandPutDef, objClass, key) || [];
      list[index] = GenerateMappingStruct(type, data);
      Reflect.defineMetadata(KoishiCommandPutDef, list, objClass, key);
    };
  }
}
